@@ -26,6 +26,7 @@ import pbr.version
 from neutron.common import config as n_config  # noqa
 
 from networking_bagpipe.bagpipe_bgp.api import api
+from networking_bagpipe.bagpipe_bgp.api import config as api_config
 from networking_bagpipe.bagpipe_bgp.common import config
 from networking_bagpipe.bagpipe_bgp.engine import exabgp_peer_worker
 from networking_bagpipe.bagpipe_bgp.vpn import dataplane_drivers as drivers
@@ -35,6 +36,7 @@ LOG = logging.getLogger(__name__)
 
 
 def setup_config():
+    api_config.register_config()
     config.register()
     cfg.CONF(args=sys.argv[1:],
              project='bagpipe-bgp',
@@ -53,6 +55,7 @@ def setup_logging():
         '%s.engine.exabgp_peer_worker.exabgp=INFO' % BAGPIPE_BGP_MODULE,
         '%s.common.looking_glass=WARNING' % BAGPIPE_BGP_MODULE,
         '%s.engine.route_table_manager=INFO' % BAGPIPE_BGP_MODULE,
+        'ovsdbapp.backend.ovs_idl.vlog=INFO',
     ]
 
     logging.set_defaults(default_log_levels=(logging.get_default_log_levels() +
@@ -106,8 +109,8 @@ def daemon_main():
         signal.signal(signal.SIGINT, stop)
 
         pecan_api.run()
-    except Exception as e:
-        LOG.exception("Error while starting BGP daemon: %s", e)
+    except Exception:
+        LOG.exception("Error while starting BGP daemon")
 
 
 def cleanup_main():
